=============
The home page
=============

The `landing page <https://pesummary.github.io/GW190412/home.html>`_ provides a
brief overview of the contents of each of the input files. We see a series of
key plots generated for each file -- in this case only the PSDs are shown -- and
the `Sampler kwargs` and `Meta data` for each of the files.

The `Sampler kwargs` includes things like the `ln_bayes_factor` for signal
versus noise, the `ln_evidence`, `sample_rate` etc. For this case, only the
number of samples for each of the files is displayed. This is because no
additional information was released to the public.

The `Meta data` includes things like the low frequency cutoff used for all
likelihood evaluations (`f_low`), the reference frequency (`f_ref`), the
cosmology used for the conversions, numerical relativity fits used to compute
the remnant quantities etc.

We also see that each of these tables can be exported to a `csv` file by
clicking on the download button.
